@@ -17,4 +17,4 @@ via = Via()
 via.init_app(app)
 
 if __name__ == '__main__':
-    app.run(debug=True)
+    app.run(debug=False)
